导入 jieba

套路 分词(语句, 全模式=假, HMM=真, 使用飞浆=假):
    """
    主要函数, 将包含中文字符的整句分割成单独的词汇. 返回一个生成器.

    '全模式' 默认为假, 即使用精确模式.
    """
    生成 自 jieba.cut(语句, cut_all=全模式, HMM=HMM, use_paddle=使用飞浆)

套路 分词列表(*参数, **关键词参数):
    """
    '分词' 函数的返回列表版本.
    """
    返回 jieba.lcut(*参数, **关键词参数)

套路 分词_搜索引擎(语句, HMM=真):
    """
    更精细分词, 用于搜索引擎. 返回一个生成器.
    """
    生成 自 jieba.cut_for_search(语句, HMM=HMM)

套路 分词列表_搜索引擎(*参数, **关键词参数):
    """
    '分词_搜索引擎' 函数的返回列表版本.
    """
    返回 jieba.lcut_for_search(*参数, **关键词参数)

套路 添加词语(词语, 词频=空, 词性=空):
    """
    添加一个词语到字典.

    '词频' 和 '词性' 可忽略.
    '词频' 默认为一个确保该词可被切分的计算值.
    """
    jieba.add_word(词语, freq=词频, tag=词性)

套路 删除词语(词语):
    """
    删除词语的便利函数.
    """
    jieba.del_word(词语)



